@@ -34,9 +34,7 @@ class Vmdb2:
         tvars = self.template_vars_from_args(args)
 
         cmd = None
-        if args.version:
-            cmd = VersionCommand(self._version)
-        elif args.image or args.output:
+        if args.image or args.output:
             if args.image:
                 cmd = ReuseImageCommand(args.image, args.specfile, args.rootfs_tarball)
             else:
@@ -59,7 +57,7 @@ class Vmdb2:
 
     def parse_command_line(self):
         p = argparse.ArgumentParser(
-            description="build disk images with Debian installed"
+            prog="vmdb2", description="build disk images with Debian installed"
         )
 
         p.add_argument("--image", metavar="FILE")
@@ -67,7 +65,15 @@ class Vmdb2:
         p.add_argument("--rootfs-tarball", metavar="FILE")
         p.add_argument("-v", "--verbose", action="store_true")
         p.add_argument("--log")
-        p.add_argument("--version", action="store_true")
+        p.add_argument("--version", action="version", version=vmdb.__version__)
+        p.add_argument(
+            "--variable",
+            action="append",
+            default=[],
+            help="Specify the value for a Jinja2 template variable in the "
+            'build spec file in the format "name=value". This parameter can '
+            "be specified multiple times to define multiple variables.",
+        )
         p.add_argument("specfile")
 
         return p.parse_args()
@@ -88,12 +94,27 @@ class Vmdb2:
         logging.info(f"Starting vmdb2 version {self._version}")
 
     def template_vars_from_args(self, args):
-        return {
+        vars = {
             "image": args.image,
             "output": args.output,
             "rootfs_tarball": args.rootfs_tarball,
         }
 
+        for var_spec in args.variable:
+            name, value = var_spec.split("=")
+            if name in vars:
+                raise RuntimeError(f'Duplicate definition of variable "{name}"')
+
+            # Remove quoes from the value if required
+            if value.startswith("'"):
+                value = value.strip("'")
+            elif value.startswith('"'):
+                value = value.strip('"')
+
+            vars[name] = value
+
+        return vars
+
 
 class Command:
     def run(self):
@@ -145,7 +166,10 @@ class ImageBuilder:
         spec = self.load_spec_file(self._specfile)
         state = vmdb.State()
         state.tags = vmdb.Tags()
-        state.arch = vmdb.runcmd(["dpkg", "--print-architecture"]).decode("UTF-8").strip()
+        state.arch = (
+            vmdb.runcmd(["dpkg", "--print-architecture"]).decode("UTF-8").strip()
+        )
+        logging.debug(f"Set state.arch={state.arch!r}")
         self.add_template_vars(state.as_dict())
         steps = spec.get_steps(self._tvars)
 
@@ -175,6 +199,7 @@ class ImageBuilder:
             vmdb.progress("Load spec file {}".format(filename))
             with open(filename) as f:
                 spec.load_file(f)
+        vmdb.progress(f"Spec:\n{spec.as_dict()}")
         return spec
 
     def load_step_runners(self):
