@@ -51,12 +51,38 @@ class MkfsStepRunner(vmdb.StepRunnerInterface):
                 cmd.append("-L")
             cmd.append(label)
 
+        # Ext4 filesystem features large_dir and metadata_csum_seed
+        # are known to make versions of GRUB older than 2.06-8 unable
+        # to boot. Keep this around at least until it is no longer
+        # likely enough(?) users will try to build older target
+        # systems.
+        if fstype == "ext4":
+            cmd.append("-O")
+            cmd.append("^large_dir")
+            cmd.append("-O")
+            cmd.append("^metadata_csum_seed")
+
         options = values["options"] or None
         if options:
-            for opt in options.split(' '):
+            for opt in options.split(" "):
                 cmd.append(opt)
 
         cmd.append(device)
         vmdb.runcmd(cmd)
 
+        uuid = (
+            vmdb.runcmd(
+                [
+                    "blkid",
+                    "-c/dev/null",
+                    "-ovalue",
+                    "-sUUID",
+                    device,
+                ]
+            )
+            .decode()
+            .strip()
+        )
+
         state.tags.set_fstype(tag, fstype)
+        state.tags.set_fsuuid(tag, uuid)
