@@ -38,7 +38,9 @@ class UnpackCacheStepRunner(vmdb.StepRunnerInterface):
         tar_path = settings["rootfs-tarball"]
         logging.debug(f"tar_path: {tar_path!r}")
         if not tar_path:
-            raise Exception("--rootfs-tarball MUST be set")
+            raise Exception(
+                "--rootfs-tarball MUST be set if using the 'unpack-rootfs' step"
+            )
         if os.path.exists(tar_path):
             vmdb.runcmd(["tar", "-C", rootdir, "-xf", tar_path, "--numeric-owner"])
             state.rootfs_unpacked = True
