@@ -1,4 +1,4 @@
 def install_vmdb2(ctx):
-    srcdeir = globals()["srcdir"]
+    srcdir = globals()["srcdir"]
     runcmd_prepend_to_path = globals()["runcmd_prepend_to_path"]
     runcmd_prepend_to_path(ctx, srcdir)
